/**
 * @file
 * JS extensions for quote_plus_fqb module.
 */

/**
 * Create our own namespace and specialized functions.
 */
Drupal.quotePlusFqb = {

  /**
   * React on clicking the toggle quote link.
   *
   * @param link
   *   The toggle link that has just been clicked.
   */
  toggleQuote: function(link) {
    var container = link.parents('div.quote-plus-fqb').filter(':first');
    var full = !container.hasClass('quote-plus-fqb-fullquote') ? 1 : 0;
    var cid = Drupal.quotePlusFqb.getCommentId(container);
    $.ajax({
      type: 'POST',
      dataType: 'json',
      data: {
        qid: Drupal.quotePlusFqb.extractId(container, 'quote-plus-fqb'),
        sid: Drupal.quotePlusFqb.extractId(container.children('span.quote-plus-fqb-sid').filter(':first'), 'quote-plus-fqb-sid'),
        cid: cid,
        full: full
      },
      url: Drupal.settings.basePath + Drupal.settings.quotePlusFqb.callbackPath,
      success: function(data) {
        var parent = container.parents('div.quote-content');
        // Some eye candy, but also helpful for the user to trace
        // what's happening.
        parent.slideUp();
        setTimeout(function() {
          // Add the replacement container directly before the old one
          // and initialize the events.
          container.before(data.content);
          Drupal.attachBehaviors(container.prev());
          // Now remove the outdated container.
          container.remove();
          // And do some more eye candy.
          parent.slideDown();
          setTimeout(function() {
            $('html, body').animate({ scrollTop: parent.offset().top });
          }, 500);
        }, 500);
      }
    });
  },

  /**
   * Extract the quote ID out of a div container's CSS ID.
   *
   * @param container
   *   An already identified div container object.
   * @param matchString
   *   The basic ID string pattern to be matched against.
   *
   * @return int
   *   A quote container's numeric quote ID.
   */
  extractId: function(container, matchString) {
    var re = new RegExp('^' + matchString + '-([0-9]+)$');
    var id = container.attr('id').match(re);
    if (typeof id == 'object') {
      return id[1];
    }
  },

  /**
   * Finds and returns the comment ID a container belongs to.
   *
   * @param container
   *   A div container object.
   *
   * @return int
   *   The comment ID.
   */
  getCommentId: function(container) {
    return Drupal.quotePlusFqb.extractId(container.parents('div.comment').filter(':first').prevAll('a').filter(':first'), 'comment');
  }
}

/**
 * Initial operations.
 */
Drupal.behaviors.quotePlusFqb = function(context) {
  // Activate AJAX on toggle links.
  $('a.quote-plus-fqb-toggle', context).each(function() {
    $(this).click(function(event) {
      Drupal.quotePlusFqb.toggleQuote($(this));
      event.preventDefault();
    });
  });
}
